@@ -13,7 +13,7 @@
 //W  nccell_duplicate
 //W  nccell_release
 //
-// functions manually reimplemented: 43
+// functions manually reimplemented: 46
 // ------------------------------------------
 // (X) wont:  2
 // (+) done: 38
@@ -61,6 +61,9 @@
 //W+ nccell_wide_left_p
 //W+ nccell_wide_right_p
 //W+ nccellcmp
+//   nccells_ascii_box
+//   nccells_heavy_box
+//   nccells_light_box
 //W+ nccells_load_box
 
 #[cfg(test)]
@@ -70,6 +73,9 @@ mod methods;
 mod reimplemented;
 pub use reimplemented::*;
 
+#[allow(unused_imports)] // TEMP
+use crate::{NcChannel, NcPlane};
+
 // NcCell
 /// A coordinate on an [`NcPlane`][crate::NcPlane] storing 128 bits of data.
 ///
@@ -83,16 +89,16 @@ pub use reimplemented::*;
 ///
 /// # Description
 ///
-/// An `NcCell` corresponds to a single character cell on some NcPlane`,
+/// An `NcCell` corresponds to a single character cell on some `NcPlane`,
 /// which can be occupied by a single [`NcEgc`] grapheme cluster (some root
 /// spacing glyph, along with possible combining characters, which might span
 /// multiple columns).
 ///
-/// An NcCell is bounded to an NcPlane, but the cell doesn't store anything
+/// An NcCell is bounded to an `NcPlane`, but the cell doesn't store anything
 /// about the plane.
 ///
 /// At any `NcCell`, we can have a theoretically arbitrarily long UTF-8 string,
-/// a foreground color, a background color, and an [`NcStyleMask`] attribute set.
+/// a foreground color, a background color, and an [`NcStyle`] attribute set.
 ///
 /// Valid grapheme cluster contents include:
 ///
@@ -108,18 +114,18 @@ pub use reimplemented::*;
 /// ```txt
 /// NcCell: 128 bits structure comprised of the following 5 elements:
 ///
-/// GCLUSTER GCLUSTER GCLUSTER GCLUSTER  1. NcEgc
-/// 00000000 ~~~~~~~~ 11111111 11111111  2. NcEgcBackstop + 3. width + 4. NcStyleMask
-/// ~~AA~~~~ RRRRRRRR GGGGGGGG BBBBBBBB  5. NcChannelPair
-/// ~~AA~~~~ RRRRRRRR GGGGGGGG BBBBBBBB  |
+/// GCLUSTER|GCLUSTER|GCLUSTER|GCLUSTER  1. NcEgc
+/// 00000000║WWWWWWWW║11111111|11111111  2. NcEgcBackstop + 3. width + 4. NcStyle
+/// ~~AA~~~~|RRRRRRRR|GGGGGGGG|BBBBBBBB  5. NcChannels
+/// ~~AA~~~~|RRRRRRRR|GGGGGGGG|BBBBBBBB     "
 ///
 /// 1. (32b) Extended Grapheme Cluster, presented either as:
 ///
 ///     1.1. An NcEgc of up to 4 bytes:
-///     UUUUUUUU UUUUUUUU UUUUUUUU UUUUUUUU
+///     UUUUUUUU|UUUUUUUU|UUUUUUUU|UUUUUUUU
 ///
 ///     1.2. A `0x01` in the first byte, plus 3 bytes with a 24b address to an egcpool:
-///     00000001 IIIIIIII IIIIIIII IIIIIIII
+///     00000001|IIIIIIII|IIIIIIII|IIIIIIII
 ///
 /// 2. (8b) Backstop (zero)
 /// 00000000
@@ -127,11 +133,11 @@ pub use reimplemented::*;
 /// 3. (8b) column width
 /// WWWWWWWW
 ///
-/// 4. (16b) NcStyleMask
+/// 4. (16b) NcStyle
 /// 11111111 11111111
 ///
-/// 5. (64b) NcChannelPair
-/// ~~AA~~~~ RRRRRRRR GGGGGGGG BBBBBBBB|~~AA~~~~ RRRRRRRR GGGGGGGG BBBBBBBB
+/// 5. (64b) NcChannels
+/// ~~AA~~~~|RRRRRRRR|GGGGGGGG|BBBBBBBB║~~AA~~~~|RRRRRRRR|GGGGGGGG|BBBBBBBB
 /// ```
 ///
 /// `type in C: cell (struct)`
@@ -158,20 +164,24 @@ pub use reimplemented::*;
 /// have two bits of inverted alpha. The actual grapheme written to a cell is
 /// the topmost non-zero grapheme.
 ///
-/// - If its alpha is 00 ([`NCCELL_ALPHA_OPAQUE`]) its foreground color is used unchanged.
+/// - If its alpha is 00 ([`NCALPHA_OPAQUE`][crate::NCALPHA_OPAQUE])
+///   its foreground color is used unchanged.
 ///
-/// - If its alpha is 10 ([`NCCELL_ALPHA_TRANSPARENT`]) its foreground color is derived
+/// - If its alpha is 10 ([`NCALPHA_TRANSPARENT`][crate::NCALPHA_TRANSPARENT])
+///   its foreground color is derived
 ///   entirely from cells underneath it.
 ///
-/// - If its alpha is 01 ([`NCCELL_ALPHA_BLEND`]) the result will be a composite.
+/// - If its alpha is 01 ([`NCALPHA_BLEND`][crate::NCALPHA_BLEND])
+///   the result will be a composite.
 ///
 /// Likewise for the background. If the bottom of a coordinate's zbuffer is
 /// reached with a cumulative alpha of zero, the default is used. In this way,
 /// a terminal configured with transparent background can be supported through
 /// multiple occluding ncplanes.
 ///
-/// A foreground alpha of 11 ([`NCCELL_ALPHA_HIGHCONTRAST`]) requests high-contrast
-/// text (relative to the computed background).
+/// A foreground alpha of 11
+/// ([`NCALPHA_HIGHCONTRAST`][crate::NCALPHA_HIGHCONTRAST])
+/// requests high-contrast text (relative to the computed background).
 /// A background alpha of 11 is currently forbidden.
 ///
 /// ## Precedence
@@ -197,88 +207,6 @@ pub use reimplemented::*;
 ///
 pub type NcCell = crate::bindings::ffi::cell;
 
-#[allow(unused_imports)]
-use crate::{NcAlphaBits, NcChannel, NcPlane};
-
-/// [`NcAlphaBits`] bits indicating
-/// [`NcCell`]'s foreground or background color will be a composite between
-/// its color and the `NcCell`s' corresponding colors underneath it
-pub const NCCELL_ALPHA_BLEND: u32 = crate::bindings::ffi::CELL_ALPHA_BLEND;
-
-/// [`NcAlphaBits`] bits indicating
-/// [`NcCell`]'s foreground color will be high-contrast (relative to the
-/// computed background). Background cannot be highcontrast
-pub const NCCELL_ALPHA_HIGHCONTRAST: u32 = crate::bindings::ffi::CELL_ALPHA_HIGHCONTRAST;
-
-/// [`NcAlphaBits`] bits indicating
-/// [`NcCell`]'s foreground or background color is used unchanged
-pub const NCCELL_ALPHA_OPAQUE: u32 = crate::bindings::ffi::CELL_ALPHA_OPAQUE;
-
-/// [`NcAlphaBits`] bits indicating
-/// [`NcCell`]'s foreground or background color is derived entirely from the
-/// `NcCell`s underneath it
-pub const NCCELL_ALPHA_TRANSPARENT: u32 = crate::bindings::ffi::CELL_ALPHA_TRANSPARENT;
-
-/// If this bit is set, we are *not* using the default background color
-///
-/// See the detailed diagram at [`NcChannelPair`][crate::NcChannelPair]
-///
-/// NOTE: This can also be used against a single [`NcChannel`]
-pub const NCCELL_BGDEFAULT_MASK: u32 = crate::bindings::ffi::CELL_BGDEFAULT_MASK;
-
-/// Extract these bits to get the background alpha mask
-/// ([`NcAlphaBits`])
-///
-/// See the detailed diagram at [`NcChannelPair`][crate::NcChannelPair]
-///
-/// NOTE: This can also be used against a single [`NcChannel`]
-pub const NCCELL_BG_ALPHA_MASK: u32 = crate::bindings::ffi::CELL_BG_ALPHA_MASK;
-
-/// If this bit *and* [`NCCELL_BGDEFAULT_MASK`] are set, we're using a
-/// palette-indexed background color
-///
-/// See the detailed diagram at [`NcChannelPair`][crate::NcChannelPair]
-///
-/// NOTE: This can also be used against a single [`NcChannel`]
-pub const NCCELL_BG_PALETTE: u32 = crate::bindings::ffi::CELL_BG_PALETTE;
-
-/// Extract these bits to get the background [`NcRgb`][crate::NcRgb] value
-///
-/// See the detailed diagram at [`NcChannelPair`][crate::NcChannelPair]
-///
-/// NOTE: This can also be used against a single [`NcChannel`]
-pub const NCCELL_BG_RGB_MASK: u32 = crate::bindings::ffi::CELL_BG_RGB_MASK;
-
-/// If this bit is set, we are *not* using the default foreground color
-///
-/// See the detailed diagram at [`NcChannelPair`][crate::NcChannelPair]
-///
-/// NOTE: When working with a single [`NcChannel`] use [`NCCELL_BGDEFAULT_MASK`];
-pub const NCCELL_FGDEFAULT_MASK: u64 = crate::bindings::ffi::CELL_FGDEFAULT_MASK;
-
-/// Extract these bits to get the foreground alpha mask
-/// ([`NcAlphaBits`])
-///
-/// See the detailed diagram at [`NcChannelPair`][crate::NcChannelPair]
-///
-/// NOTE: When working with a single [`NcChannel`] use [`NCCELL_BG_ALPHA_MASK`];
-pub const NCCELL_FG_ALPHA_MASK: u64 = crate::bindings::ffi::CELL_FG_ALPHA_MASK;
-
-/// If this bit *and* [`NCCELL_FGDEFAULT_MASK`] are set, we're using a
-/// palette-indexed background color
-///
-/// See the detailed diagram at [`NcChannelPair`][crate::NcChannelPair]
-///
-/// NOTE: When working with a single [`NcChannel`] use [`NCCELL_BG_PALETTE`];
-pub const NCCELL_FG_PALETTE: u64 = crate::bindings::ffi::CELL_FG_PALETTE;
-
-/// Extract these bits to get the foreground [`NcRgb`][crate::NcRgb] value
-///
-/// See the detailed diagram at [`NcChannelPair`][crate::NcChannelPair]
-///
-/// NOTE: When working with a single [`NcChannel`] use [`NCCELL_BG_RGB_MASK`];
-pub const NCCELL_FG_RGB_MASK: u64 = crate::bindings::ffi::CELL_FG_RGB_MASK;
-
 // NcEgc
 //
 /// Extended Grapheme Cluster. A 32-bit [`char`]-like type
@@ -319,7 +247,7 @@ pub const NCCELL_FG_RGB_MASK: u64 = crate::bindings::ffi::CELL_FG_RGB_MASK;
 /// in a cell, and therefore it must not be allowed through the API.
 ///
 /// -----
-/// NOTE that even if the `NcEgc` is <= 4 bytes and inlined, is still interpreted as
+/// Note that even if the `NcEgc` is <= 4 bytes and inlined, is still interpreted as
 /// a NUL-terminated char * (technically, &cell->gcluster is treated as a char*).
 /// If it is more than 4 bytes, cell->gcluster has a first byte of 0x01,
 /// and the remaining 24 bits are an index into the plane's egcpool,
@@ -349,25 +277,25 @@ pub type NcEgc = char;
 ///
 pub type NcEgcBackstop = u8;
 
-// NcStyleMask
+// NcStyle
 ///
 /// An `u16` of `NCSTYLE_*` boolean styling attribute flags
 ///
 /// ## Attributes
 ///
-/// - [`NCSTYLE_BLINK`]
-/// - [`NCSTYLE_BOLD`]
-/// - [`NCSTYLE_DIM`]
-/// - [`NCSTYLE_INVIS`]
-/// - [`NCSTYLE_ITALIC`]
 /// - [`NCSTYLE_MASK`]
-/// - [`NCSTYLE_NONE`]
-/// - [`NCSTYLE_PROTECT`]
-/// - [`NCSTYLE_REVERSE`]
-/// - [`NCSTYLE_STANDOUT`]
+/// - [`NCSTYLE_UNDERCURL`]
 /// - [`NCSTYLE_STRUCK`]
+/// - [`NCSTYLE_ITALIC`]
+/// - [`NCSTYLE_STANDOUT`]
 /// - [`NCSTYLE_UNDERLINE`]
-///
+/// - [`NCSTYLE_REVERSE`]
+/// - [`NCSTYLE_BLINK`]
+/// - [`NCSTYLE_DIM`]
+/// - [`NCSTYLE_BOLD`]
+/// - [`NCSTYLE_INVIS`]
+/// - [`NCSTYLE_PROTECT`]
+/// - [`NCSTYLE_NONE`]
 ///
 /// ## Diagram
 ///
@@ -377,40 +305,43 @@ pub type NcEgcBackstop = u8;
 ///
 /// `type in C:  uint16_t`
 ///
-pub type NcStyleMask = u16;
-
-///
-pub const NCSTYLE_BLINK: u16 = crate::bindings::ffi::NCSTYLE_BLINK as u16;
-
-///
-pub const NCSTYLE_BOLD: u16 = crate::bindings::ffi::NCSTYLE_BOLD as u16;
-
-///
-pub const NCSTYLE_DIM: u16 = crate::bindings::ffi::NCSTYLE_DIM as u16;
-
-///
-pub const NCSTYLE_INVIS: u16 = crate::bindings::ffi::NCSTYLE_INVIS as u16;
-
-///
-pub const NCSTYLE_ITALIC: u16 = crate::bindings::ffi::NCSTYLE_ITALIC as u16;
+pub type NcStyle = u16;
 
 ///
 pub const NCSTYLE_MASK: u16 = crate::bindings::ffi::NCSTYLE_MASK as u16;
 
 ///
-pub const NCSTYLE_NONE: u16 = crate::bindings::ffi::NCSTYLE_NONE as u16;
-
-///
-pub const NCSTYLE_PROTECT: u16 = crate::bindings::ffi::NCSTYLE_PROTECT as u16;
-
-///
-pub const NCSTYLE_REVERSE: u16 = crate::bindings::ffi::NCSTYLE_REVERSE as u16;
-
-///
-pub const NCSTYLE_STANDOUT: u16 = crate::bindings::ffi::NCSTYLE_STANDOUT as u16;
+pub const NCSTYLE_UNDERCURL: u16 = crate::bindings::ffi::NCSTYLE_UNDERCURL as u16;
 
 ///
 pub const NCSTYLE_STRUCK: u16 = crate::bindings::ffi::NCSTYLE_STRUCK as u16;
 
+///
+pub const NCSTYLE_ITALIC: u16 = crate::bindings::ffi::NCSTYLE_ITALIC as u16;
+
+///
+pub const NCSTYLE_STANDOUT: u16 = crate::bindings::ffi::NCSTYLE_STANDOUT as u16;
+
 ///
 pub const NCSTYLE_UNDERLINE: u16 = crate::bindings::ffi::NCSTYLE_UNDERLINE as u16;
+
+///
+pub const NCSTYLE_REVERSE: u16 = crate::bindings::ffi::NCSTYLE_REVERSE as u16;
+
+///
+pub const NCSTYLE_BLINK: u16 = crate::bindings::ffi::NCSTYLE_BLINK as u16;
+
+///
+pub const NCSTYLE_DIM: u16 = crate::bindings::ffi::NCSTYLE_DIM as u16;
+
+///
+pub const NCSTYLE_BOLD: u16 = crate::bindings::ffi::NCSTYLE_BOLD as u16;
+
+///
+pub const NCSTYLE_INVIS: u16 = crate::bindings::ffi::NCSTYLE_INVIS as u16;
+
+///
+pub const NCSTYLE_PROTECT: u16 = crate::bindings::ffi::NCSTYLE_PROTECT as u16;
+
+///
+pub const NCSTYLE_NONE: u16 = crate::bindings::ffi::NCSTYLE_NONE as u16;
