@@ -1,32 +1,32 @@
-//! `Notcurses*` methods and associated functions.
+//! `Nc*` methods and associated functions.
 
 use core::ptr::{null, null_mut};
 
 use crate::{
-    cstring, error, error_ref_mut, notcurses_init, rstring, NcAlign, NcBlitter, NcChannelPair,
-    NcDim, NcEgc, NcError, NcFile, NcInput, NcLogLevel, NcPlane, NcResult, NcScale, NcSignalSet,
-    NcStats, NcStyleMask, NcTime, Notcurses, NotcursesOptions, NCOPTION_NO_ALTERNATE_SCREEN,
-    NCOPTION_SUPPRESS_BANNERS, NCRESULT_ERR,
+    cstring, error, error_ref_mut, notcurses_init, rstring, Nc, NcAlign, NcBlitter, NcChannels,
+    NcDim, NcEgc, NcError, NcFile, NcInput, NcLogLevel, NcOptions, NcPlane, NcResult, NcScale,
+    NcSignalSet, NcStats, NcStyle, NcTime, NCOPTION_NO_ALTERNATE_SCREEN, NCOPTION_SUPPRESS_BANNERS,
+    NCRESULT_ERR,
 };
 
-/// # `NotcursesOptions` Constructors
-impl NotcursesOptions {
-    /// New NotcursesOptions.
+/// # `NcOptions` Constructors
+impl NcOptions {
+    /// New NcOptions.
     pub const fn new() -> Self {
         Self::with_all_options(0, 0, 0, 0, 0, 0)
     }
 
-    /// New NotcursesOptions, with margins.
+    /// New NcOptions, with margins.
     pub const fn with_margins(top: NcDim, right: NcDim, bottom: NcDim, left: NcDim) -> Self {
         Self::with_all_options(0, top, right, bottom, left, 0)
     }
 
-    /// New NotcursesOptions, with flags.
+    /// New NcOptions, with flags.
     pub const fn with_flags(flags: u64) -> Self {
         Self::with_all_options(0, 0, 0, 0, 0, flags)
     }
 
-    /// New NotcursesOptions, with all the options.
+    /// New NcOptions, with all the options.
     ///
     /// ## Arguments
     ///
@@ -78,46 +78,44 @@ impl NotcursesOptions {
     }
 }
 
-/// # `Notcurses` Constructors
-impl Notcurses {
-    /// New Notcurses (without banners).
-    pub fn new<'a>() -> NcResult<&'a mut Notcurses> {
+/// # `Nc` Constructors
+impl Nc {
+    /// New notcurses context (without banners).
+    pub fn new<'a>() -> NcResult<&'a mut Nc> {
         Self::with_flags(NCOPTION_SUPPRESS_BANNERS)
     }
 
-    /// New Notcurses, with banners.
+    /// New notcurses context, with banners.
     ///
     /// This is the default in the C library.
-    pub fn with_banners<'a>() -> NcResult<&'a mut Notcurses> {
+    pub fn with_banners<'a>() -> NcResult<&'a mut Nc> {
         Self::with_flags(0)
     }
 
-    /// New Notcurses, without an alternate screen (nor banners).
-    pub fn without_altscreen<'a>() -> NcResult<&'a mut Notcurses> {
+    /// New notcurses context, without an alternate screen (nor banners).
+    pub fn without_altscreen<'a>() -> NcResult<&'a mut Nc> {
         Self::with_flags(NCOPTION_NO_ALTERNATE_SCREEN | NCOPTION_SUPPRESS_BANNERS)
     }
 
-    /// New Notcurses, expects `NCOPTION_*` flags.
-    pub fn with_flags<'a>(flags: u64) -> NcResult<&'a mut Notcurses> {
-        Self::with_options(NotcursesOptions::with_flags(flags))
+    /// New notcurses context, expects `NCOPTION_*` flags.
+    pub fn with_flags<'a>(flags: u64) -> NcResult<&'a mut Nc> {
+        Self::with_options(NcOptions::with_flags(flags))
     }
 
-    /// New Notcurses, expects [NotcursesOptions].
-    pub fn with_options<'a>(options: NotcursesOptions) -> NcResult<&'a mut Notcurses> {
+    /// New notcurses context, expects [NcOptions].
+    pub fn with_options<'a>(options: NcOptions) -> NcResult<&'a mut Nc> {
         let res = unsafe { notcurses_init(&options, null_mut()) };
         error_ref_mut![res, "Notcurses.with_options()"]
     }
 
-    /// New Notcurses, expects [NcLogLevel] and flags.
-    pub fn with_debug<'a>(loglevel: NcLogLevel, flags: u64) -> NcResult<&'a mut Notcurses> {
-        Self::with_options(NotcursesOptions::with_all_options(
-            loglevel, 0, 0, 0, 0, flags,
-        ))
+    /// New notcurses context, expects [NcLogLevel] and flags.
+    pub fn with_debug<'a>(loglevel: NcLogLevel, flags: u64) -> NcResult<&'a mut Nc> {
+        Self::with_options(NcOptions::with_all_options(loglevel, 0, 0, 0, 0, flags))
     }
 }
 
-/// # `Notcurses` methods
-impl Notcurses {
+/// # `Nc` methods
+impl Nc {
     /// Returns the offset into `availcols` at which `cols` ought be output given
     /// the requirements of `align`.
     ///
@@ -133,7 +131,7 @@ impl Notcurses {
 
     /// Retrieves the current contents of the specified [NcCell][crate::NcCell]
     /// as last rendered, returning the [NcEgc] (or None on error) and writing
-    /// out the [NcStyleMask] and the [NcChannelPair].
+    /// out the [NcStyle] and the [NcChannels].
     ///
     /// This NcEgc must be freed by the caller.
     ///
@@ -142,8 +140,8 @@ impl Notcurses {
         &mut self,
         y: NcDim,
         x: NcDim,
-        stylemask: &mut NcStyleMask,
-        channels: &mut NcChannelPair,
+        stylemask: &mut NcStyle,
+        channels: &mut NcChannels,
     ) -> Option<NcEgc> {
         let egc = unsafe { crate::notcurses_at_yx(self, x as i32, y as i32, stylemask, channels) };
         if egc.is_null() {
@@ -153,7 +151,8 @@ impl Notcurses {
         Some(egc)
     }
 
-    /// Returns the bottommost [NcPlane], of which there is always at least one.
+    /// Returns the bottommost [NcPlane] on the standard pile,
+    /// of which there is always at least one.
     ///
     /// *C style function: [notcurses_bottom()][crate::notcurses_bottom].*
     pub fn bottom(&mut self) -> &mut NcPlane {
@@ -260,7 +259,7 @@ impl Notcurses {
     ///
     /// *C style function: [notcurses_check_pixel_support()][crate::notcurses_check-pixel_support].*
     #[allow(clippy::wildcard_in_or_patterns)]
-    pub fn check_pixel_support(&mut self) -> NcResult<bool> {
+    pub fn check_pixel_support(&self) -> NcResult<bool> {
         let res = unsafe { crate::notcurses_check_pixel_support(self) };
         match res {
             0 => Ok(false),
@@ -288,7 +287,7 @@ impl Notcurses {
         error![unsafe { crate::notcurses_cursor_enable(self, y as i32, x as i32) }]
     }
 
-    /// Dumps Notcurses state to the supplied `debugfp`.
+    /// Dumps notcurses state to the supplied `debugfp`.
     ///
     /// Output is freeform, and subject to change. It includes geometry of all
     /// planes, from all piles.
@@ -311,6 +310,13 @@ impl Notcurses {
         }
     }
 
+    /// Returns the name of the detected terminal.
+    ///
+    /// *C style function: [notcurses_detected_terminal()][crate::notcurses_detected_terminal].*
+    pub fn detected_terminal(&self) -> String {
+        rstring![crate::notcurses_detected_terminal(self)].to_string()
+    }
+
     /// Destroys all [NcPlane]s other than the stdplane.
     ///
     /// *C style function: [notcurses_drop_planes()][crate::notcurses_drop_planes].*
@@ -397,18 +403,14 @@ impl Notcurses {
         if res as u32 as i32 != -1 {
             Ok(res)
         } else {
-            error![
-                -1,
-                &format!("Notcurses.getc_blocking({:?})", input_txt),
-                res
-            ]
+            error![-1, &format!("Nc.getc_blocking({:?})", input_txt), res]
         }
     }
 
     /// Gets a file descriptor suitable for input event poll()ing.
     ///
     /// When this descriptor becomes available, you can call
-    /// [getc_nblock()][Notcurses#method.getc_nblock], and input ought be ready.
+    /// [getc_nblock()][Nc#method.getc_nblock], and input ought be ready.
     ///
     /// This file descriptor is not necessarily the file descriptor associated
     /// with stdin (but it might be!).
@@ -429,13 +431,13 @@ impl Notcurses {
         ]
     }
 
-    /// Lexes a margin argument according to the standard Notcurses definition.
+    /// Lexes a margin argument according to the standard notcurses definition.
     ///
     /// There can be either a single number, which will define all margins equally,
     /// or there can be four numbers separated by commas.
     ///
     /// *C style function: [notcurses_lex_margins()][crate::notcurses_lex_margins].*
-    pub fn lex_margins(op: &str, options: &mut NotcursesOptions) -> NcResult<()> {
+    pub fn lex_margins(op: &str, options: &mut NcOptions) -> NcResult<()> {
         error![unsafe { crate::notcurses_lex_margins(cstring![op], options) }]
     }
 
@@ -478,13 +480,13 @@ impl Notcurses {
     /// Enable the mouse in "button-event tracking" mode with focus detection
     /// and UTF8-style extended coordinates.
     ///
-    /// On success, mouse events will be published to [getc()][Notcurses#method.getc].
+    /// On success, mouse events will be published to [getc()][Nc#method.getc].
     ///
     /// *C style function: [notcurses_mouse_enable()][crate::notcurses_mouse_enable].*
     pub fn mouse_enable(&mut self) -> NcResult<()> {
         error![
             unsafe { crate::notcurses_mouse_enable(self) },
-            "Notcurses.mouse_enable()"
+            "Nc.mouse_enable()"
         ]
     }
 
@@ -495,20 +497,19 @@ impl Notcurses {
     /// actually support, downsampling internally.
     ///
     /// *C style function: [notcurses_palette_size()][crate::notcurses_palette_size].*
-    pub fn palette_size(&mut self) -> NcResult<u32> {
+    pub fn palette_size(&self) -> NcResult<u32> {
         let res = unsafe { crate::notcurses_palette_size(self) };
         if res == 1 {
-            return Err(NcError::with_msg(
-                1,
-                "No color support ← Notcurses.palette_size()",
-            ));
+            return Err(NcError::with_msg(1, "No color support ← Nc.palette_size()"));
         }
         Ok(res)
     }
 
     /// Refreshes the physical screen to match what was last rendered (i.e.,
     /// without reflecting any changes since the last call to
-    /// [render][crate::Notcurses#method.render]).
+    /// [render][crate::Nc#method.render]).
+    ///
+    /// Returns the current screen geometry (`y`, `x`).
     ///
     /// This is primarily useful if the screen is externally corrupted, or if an
     /// [NCKEY_RESIZE][crate::NCKEY_RESIZE] event has been read and you're not
@@ -529,14 +530,11 @@ impl Notcurses {
     ///
     /// *C style function: [notcurses_render()][crate::notcurses_render].*
     pub fn render(&mut self) -> NcResult<()> {
-        error![
-            unsafe { crate::notcurses_render(self) },
-            "Notcurses.render()"
-        ]
+        error![unsafe { crate::notcurses_render(self) }, "Nc.render()"]
     }
 
     /// Performs the rendering and rasterization portion of
-    /// [render][Notcurses#method.render] but do not write the resulting buffer
+    /// [render][Nc#method.render] but do not write the resulting buffer
     /// out to the terminal.
     ///
     /// Using this function, the user can control the writeout process,
@@ -562,7 +560,7 @@ impl Notcurses {
 
     /// Writes the last rendered frame, in its entirety, to 'fp'.
     ///
-    /// If [render()][Notcurses#method.render] has not yet been called,
+    /// If [render()][Nc#method.render] has not yet been called,
     /// nothing will be written.
     ///
     /// *C style function: [notcurses_render_to_file()][crate::notcurses_render_to_file].*
@@ -570,7 +568,7 @@ impl Notcurses {
         error![unsafe { crate::notcurses_render_to_file(self, fp.as_nc_ptr()) }]
     }
 
-    /// Acquires an atomic snapshot of the Notcurses object's stats.
+    /// Acquires an atomic snapshot of the notcurses object's stats.
     ///
     /// *C style function: [notcurses_stats()][crate::notcurses_stats].*
     pub fn stats(&mut self, stats: &mut NcStats) {
@@ -579,10 +577,10 @@ impl Notcurses {
         }
     }
 
-    /// Allocates an ncstats object.
+    /// Allocates an [`NcStats`] object.
     ///
     /// Use this rather than allocating your own, since future versions of
-    /// Notcurses might enlarge this structure.
+    /// notcurses might enlarge this structure.
     ///
     /// *C style function: [notcurses_stats_alloc()][crate::notcurses_stats_alloc].*
     pub fn stats_alloc(&mut self) -> &mut NcStats {
@@ -646,7 +644,7 @@ impl Notcurses {
         unsafe { &*crate::notcurses_stdplane_const(self) }
     }
 
-    /// Destroys the Notcurses context.
+    /// Destroys the notcurses context.
     ///
     /// *C style function: [notcurses_stop()][crate::notcurses_stop].*
     pub fn stop(&mut self) -> NcResult<()> {
@@ -667,7 +665,7 @@ impl Notcurses {
         rstring![crate::notcurses_str_scalemode(scalemode)].to_string()
     }
 
-    /// Returns an [NcStyleMask] with the supported curses-style attributes.
+    /// Returns an [NcStyle] with the supported curses-style attributes.
     ///
     /// The attribute is only indicated as supported if the terminal can support
     /// it together with color.
@@ -675,8 +673,8 @@ impl Notcurses {
     /// For more information, see the "ncv" capability in terminfo(5).
     ///
     /// *C style function: [notcurses_supported_styles()][crate::notcurses_supported_styles].*
-    pub fn supported_styles(&self) -> NcStyleMask {
-        unsafe { crate::notcurses_supported_styles(self) as NcStyleMask }
+    pub fn supported_styles(&self) -> NcStyle {
+        unsafe { crate::notcurses_supported_styles(self) as NcStyle }
     }
 
     /// Returns our current idea of the terminal dimensions in rows and cols.
@@ -700,7 +698,7 @@ impl Notcurses {
         rstring![crate::notcurses_version()].to_string()
     }
 
-    /// Returns the running Notcurses version components
+    /// Returns the running notcurses version components
     /// (major, minor, patch, tweak).
     ///
     /// *C style function: [notcurses_version_components()][crate::notcurses_version_components].*
