@@ -3,8 +3,8 @@
 use core::ptr::null_mut;
 
 use crate::{
-    cstring, nccell_release, NcAlign, NcAlphaBits, NcBoxMask, NcCell, NcChannel, NcChannelPair,
-    NcColor, NcDim, NcEgc, NcIntResult, NcPlane, NcRgb, NcStyleMask, NCRESULT_ERR, NCRESULT_OK,
+    cstring, nccell_release, NcAlign, NcAlphaBits, NcBoxMask, NcCell, NcChannel, NcChannels,
+    NcComponent, NcDim, NcEgc, NcIntResult, NcPlane, NcRgb, NcStyle, NCRESULT_ERR, NCRESULT_OK,
 };
 
 // Alpha -----------------------------------------------------------------------
@@ -44,65 +44,65 @@ pub fn ncplane_bchannel(plane: &NcPlane) -> NcChannel {
 }
 
 /// Sets the foreground [NcChannel] on an [NcPlane],
-/// and returns the new [NcChannelPair].
+/// and returns the new [NcChannels].
 ///
 /// *Method: NcPlane.[set_fchannel()][NcPlane#method.set_fchannel].*
 #[inline]
-pub fn ncplane_set_fchannel(plane: &mut NcPlane, channel: NcChannel) -> NcChannelPair {
+pub fn ncplane_set_fchannel(plane: &mut NcPlane, channel: NcChannel) -> NcChannels {
     unsafe { crate::ffi::ncplane_set_fchannel(plane, channel) }
 }
 
 /// Sets the background [NcChannel] on an [NcPlane],
-/// and returns the new [NcChannelPair].
+/// and returns the new [NcChannels].
 ///
 /// *Method: NcPlane.[set_bchannel()][NcPlane#method.set_bchannel].*
 #[inline]
-pub fn ncplane_set_bchannel(plane: &mut NcPlane, channel: NcChannel) -> NcChannelPair {
+pub fn ncplane_set_bchannel(plane: &mut NcPlane, channel: NcChannel) -> NcChannels {
     unsafe { crate::ffi::ncplane_set_bchannel(plane, channel) }
 }
 
-/// Gets the [NcChannelPair] of an [NcPlane].
+/// Gets the [NcChannels] of an [NcPlane].
 ///
 /// *Method: NcPlane.[channels()][NcPlane#method.channels].*
 #[inline]
-pub fn ncplane_channels(plane: &NcPlane) -> NcChannelPair {
+pub fn ncplane_channels(plane: &NcPlane) -> NcChannels {
     unsafe { crate::ffi::ncplane_channels(plane) }
 }
 
-/// Sets the [NcChannelPair] of an [NcPlane].
+/// Sets the [NcChannels] of an [NcPlane].
 ///
 /// *Method: NcPlane.[set_channels()][NcPlane#method.set_channels].*
 #[inline]
-pub fn ncplane_set_channels(plane: &mut NcPlane, channels: NcChannelPair) {
+pub fn ncplane_set_channels(plane: &mut NcPlane, channels: NcChannels) {
     unsafe { crate::ffi::ncplane_set_channels(plane, channels) };
 }
 
-// NcColor ---------------------------------------------------------------------
+// NcComponent ---------------------------------------------------------------------
 
-/// Gets the foreground [NcColor] RGB components from an [NcPlane].
+/// Gets the foreground RGB [NcComponent]s from an [NcPlane].
 /// and returns the background [NcChannel].
 ///
 /// *Method: NcPlane.[fg_rgb8()][NcPlane#method.fg_rgb8].*
 #[inline]
 pub fn ncplane_fg_rgb8(
     plane: &NcPlane,
-    red: &mut NcColor,
-    green: &mut NcColor,
-    blue: &mut NcColor,
+    red: &mut NcComponent,
+    green: &mut NcComponent,
+    blue: &mut NcComponent,
 ) -> NcChannel {
     crate::ncchannels_fg_rgb8(ncplane_channels(plane), red, green, blue)
 }
 
-/// Gets the background [NcColor] RGB components from an [NcPlane],
+/// Gets the background RGB [NcComponent]s from an [NcPlane],
 /// and returns the background [NcChannel].
 ///
 /// *Method: NcPlane.[bg_rgb8()][NcPlane#method.bg_rgb8].*
 #[inline]
 pub fn ncplane_bg_rgb8(
     plane: &NcPlane,
-    red: &mut NcColor,
-    green: &mut NcColor,
-    blue: &mut NcColor,
+    red: &mut NcComponent,
+    green: &mut NcComponent,
+    blue: &mut NcComponent,
 ) -> NcChannel {
     crate::ncchannels_bg_rgb8(ncplane_channels(plane), red, green, blue)
 }
@@ -144,50 +144,50 @@ pub fn ncplane_bg_default_p(plane: &NcPlane) -> bool {
 }
 
 /// Marks both the foreground and background as using the "default color",
-/// and returns the new [NcChannelPair].
+/// and returns the new [NcChannels].
 ///
 /// *Method: NcPlane.[set_default()][NcPlane#method.set_default].*
 //
 // Not in the C API.
 #[inline]
-pub fn ncplane_set_default(plane: &mut NcPlane) -> NcChannelPair {
+pub fn ncplane_set_default(plane: &mut NcPlane) -> NcChannels {
     let channels = crate::ncchannels_set_default(&mut ncplane_channels(plane));
     ncplane_set_channels(plane, channels);
     channels
 }
 
 /// Marks both the foreground and background as NOT using the "default color",
-/// and returns the new [NcChannelPair].
+/// and returns the new [NcChannels].
 ///
 /// *Method: NcPlane.[set_not_default()][NcPlane#method.set_not_default].*
 //
 // Not in the C API.
 #[inline]
-pub fn ncplane_set_not_default(plane: &mut NcPlane) -> NcChannelPair {
+pub fn ncplane_set_not_default(plane: &mut NcPlane) -> NcChannels {
     let channels = crate::ncchannels_set_not_default(&mut ncplane_channels(plane));
     crate::ncplane_set_channels(plane, channels);
     channels
 }
 
 /// Marks the foreground as NOT using the "default color",
-/// and returns the new [NcChannelPair].
+/// and returns the new [NcChannels].
 ///
 /// *Method: NcPlane.[set_fg_not_default()][NcPlane#method.set_fg_not_default].*
 //
 // Not in the C API.
 #[inline]
-pub fn ncplane_set_fg_not_default(plane: &NcPlane) -> NcChannelPair {
+pub fn ncplane_set_fg_not_default(plane: &NcPlane) -> NcChannels {
     crate::ncchannels_set_fg_not_default(&mut ncplane_channels(plane))
 }
 
 /// Marks the background as NOT using the "default color",
-/// and returns the new [NcChannelPair].
+/// and returns the new [NcChannels].
 ///
 /// *Method: NcPlane.[set_bg_not_default()][NcPlane#method.set_bg_not_default].*
 //
 // Not in the C API.
 #[inline]
-pub fn ncplane_set_bg_not_default(plane: &NcPlane) -> NcChannelPair {
+pub fn ncplane_set_bg_not_default(plane: &NcPlane) -> NcChannels {
     crate::ncchannels_set_bg_not_default(&mut ncplane_channels(plane))
 }
 
@@ -207,7 +207,7 @@ pub fn ncplane_putc(plane: &mut NcPlane, cell: &NcCell) -> NcIntResult {
 #[inline]
 pub fn ncplane_putchar(plane: &mut NcPlane, ch: char) -> NcIntResult {
     unsafe {
-        let cell = NcCell::with_char(ch, plane);
+        let cell = NcCell::from_char(ch, plane);
         crate::ncplane_putc_yx(plane, -1, -1, &cell)
     }
 }
@@ -219,7 +219,7 @@ pub fn ncplane_putchar(plane: &mut NcPlane, ch: char) -> NcIntResult {
 #[inline]
 pub fn ncplane_putchar_yx(plane: &mut NcPlane, y: NcDim, x: NcDim, ch: char) -> NcIntResult {
     unsafe {
-        let cell = NcCell::with_char(ch, plane);
+        let cell = NcCell::from_char(ch, plane);
         crate::ncplane_putc_yx(plane, y as i32, x as i32, &cell)
     }
 }
@@ -410,8 +410,8 @@ pub fn ncplane_perimeter(
 #[inline]
 pub fn ncplane_perimeter_double(
     plane: &mut NcPlane,
-    stylemask: NcStyleMask,
-    channels: NcChannelPair,
+    stylemask: NcStyle,
+    channels: NcChannels,
     boxmask: NcBoxMask,
 ) -> NcIntResult {
     if unsafe { crate::ncplane_cursor_move_yx(plane, 0, 0) } != NCRESULT_OK {
@@ -472,8 +472,8 @@ pub fn ncplane_perimeter_double(
 #[inline]
 pub fn ncplane_perimeter_rounded(
     plane: &mut NcPlane,
-    stylemask: NcStyleMask,
-    channels: NcChannelPair,
+    stylemask: NcStyle,
+    channels: NcChannels,
     boxmask: NcBoxMask,
 ) -> NcIntResult {
     if unsafe { crate::ncplane_cursor_move_yx(plane, 0, 0) } != NCRESULT_OK {
@@ -575,8 +575,8 @@ pub fn ncplane_box_sized(
 #[inline]
 pub fn ncplane_double_box(
     plane: &mut NcPlane,
-    stylemask: NcStyleMask,
-    channels: NcChannelPair,
+    stylemask: NcStyle,
+    channels: NcChannels,
     y_stop: NcDim,
     x_stop: NcDim,
     boxmask: NcBoxMask,
@@ -634,8 +634,8 @@ pub fn ncplane_double_box(
 #[inline]
 pub fn ncplane_double_box_sized(
     plane: &mut NcPlane,
-    stylemask: NcStyleMask,
-    channels: NcChannelPair,
+    stylemask: NcStyle,
+    channels: NcChannels,
     y_len: NcDim,
     x_len: NcDim,
     boxmask: NcBoxMask,
@@ -660,8 +660,8 @@ pub fn ncplane_double_box_sized(
 #[inline]
 pub fn ncplane_rounded_box(
     plane: &mut NcPlane,
-    stylemask: NcStyleMask,
-    channels: NcChannelPair,
+    stylemask: NcStyle,
+    channels: NcChannels,
     y_stop: NcDim,
     x_stop: NcDim,
     boxmask: NcBoxMask,
@@ -718,8 +718,8 @@ pub fn ncplane_rounded_box(
 #[inline]
 pub fn ncplane_rounded_box_sized(
     plane: &mut NcPlane,
-    stylemask: NcStyleMask,
-    channels: NcChannelPair,
+    stylemask: NcStyle,
+    channels: NcChannels,
     y_len: NcDim,
     x_len: NcDim,
     boxmask: NcBoxMask,
@@ -750,7 +750,7 @@ pub fn ncplane_rounded_box_sized(
 pub fn ncplane_gradient_sized(
     plane: &mut NcPlane,
     egc: &NcEgc,
-    stylemask: NcStyleMask,
+    stylemask: NcStyle,
     ul: NcChannel,
     ur: NcChannel,
     ll: NcChannel,
