@@ -9,8 +9,8 @@ use crate::{
 impl NcMenu {
     /// Creates an [NcMenu] with the specified options.
     ///
-    /// Menus are currently bound to an overall [Nc][crate::Nc] object
-    /// (as opposed to a particular plane), and are implemented as
+    /// Menus are currently bound to an overall [Notcurses][crate::Notcurses]
+    /// object (as opposed to a particular plane), and are implemented as
     /// [NcPlane]s kept atop other NcPlanes.
     ///
     /// *C style function: [ncmenu_create()][crate::ncmenu_create].*
@@ -157,10 +157,11 @@ impl NcMenu {
             ninput = null_mut();
         }
         let res = unsafe { crate::ncmenu_selected(self, ninput) };
-        if res != null_mut() {
-            return Some(unsafe { (&*res).to_string() });
+        if !res.is_null() {
+            Some(unsafe { (&*res).to_string() })
+        } else {
+            None
         }
-        None
     }
 
     /// Unrolls the specified [NcMenuSection][crate::NcMenuSection],
