@@ -16,17 +16,17 @@ impl NcTreeItem {
     /// Creates an [NcTreeItem].
     pub fn new(curry: &str, subs: Option<&mut [NcTreeItem]>, subcount: usize) -> Self {
         if let Some(subs) = subs {
-            return Self {
+            Self {
                 curry: CString::new(curry).unwrap().into_raw() as *mut _ as *mut c_void,
                 subs: subs.as_mut_ptr(),
                 subcount: subcount as u32,
-            };
+            }
         } else {
-            return Self {
+            Self {
                 curry: CString::new(curry).unwrap().into_raw() as *mut _ as *mut c_void,
                 subs: null_mut(),
                 subcount: subcount as u32,
-            };
+            }
         }
     }
 }
